<?php

/**
 * Třída Anketa (Pool)
 */

class Pool {
    
    // Identifikátor Ankety
    private $pool_name;
    // Anketní otázka
    private $question;
    // Volby ankety
    private $choices_text = array();
    // Počet hlasů k volbám ankety
    private $choices_count = array();
    // Zákaz hlasování na určitou dobu (využívá Cookie)
    private $disable_choicing;    
    // Soubor ukládající data ankety
    private $datafile;
    // Volba hlasování uživatele
    private $make_choice;
    
    
    // Konstruktor - nastavení datového souboru, identifikátoru ankety, počtu sekund platnosti Cookie
    public function __construct($datafile, $pool_name, $seconds) 
    {
        $this->datafile = $datafile;
        $this->pool_name = $pool_name;
        $this->disable_choicing = $seconds;
        $this->setChoicesCount(); 
        
        // Bylo hlasováno? Resp. obsahuje URL parametr názvu ankety?
        if (filter_has_var(INPUT_GET, $this->pool_name)) {
            $this->make_choice = filter_input(INPUT_GET, $this->pool_name, FILTER_SANITIZE_NUMBER_INT);
            $this->setNewChoices();
        }
    }
    
    // Nastavení anketní otázky
    public function setQuestion($question) 
    {
        $this->question = $question;
    }
    
    // Nastavení textu voleb ankety
    public function setChoicesText($choices_text = array())
    {
        $this->choices_text = $choices_text;
    }
    
    // Nastavení počtu hlasů (pole)
    private function setChoicesCount()
    {
        $data = file_get_contents($this->datafile);
        $this->choices_count = explode("|", $data);
    }
    
    // Nastavení navýšení počtu hlasů k zvolené volbě o +1
    private function setNewChoices() 
    {
        // Podmínka - Kontrola
        if ($this->make_choice < count($this->choices_count) && !filter_has_var(INPUT_COOKIE, $this->pool_name)) {
            
            $this->choices_count[$this->make_choice]++;
            $this->saveChoices();
            $this->setCookies();
        }        
    }
    
    // Uložení hlasování do datového souboru
    private function saveChoices() 
    {
        $data = implode("|", $this->choices_count);
        file_put_contents($this->datafile, $data);                             
    }
    
    // Nastavení Cookie pro zabránění hlasování
    private function setCookies()
    {
        // Argumenty (identifikátor, hodnota, platnost)
        setcookie($this->pool_name, 111, time() + $this->disable_choicing);
    }    
    
    // Získání identifikátoru ankety
    public function getPoolName()
    {
        return $this->pool_name;
    }
    
    // Získání anketní otázky
    public function getQuestion()
    {
        return $this->question;
    }
    
    // Získání textu všech voleb ankety (array)
    public function getAllChoices()
    {
        return $this->choices_text;    
    }
    
    // Získání textu jedné volby z pole
    public function getChoiceText($key)
    {
        return $this->choices_text[$key];
    }

    // Získání počtu hlasů jedné z voleb
    public function getChoiceCount($key)
    {
        return (int) $this->choices_count[$key];
    }    
    
    // Získání součtu všech hlasů ankety
    public function getChoicesSum() 
    {
        return (int) array_sum($this->choices_count);
    }
    
    // Získání šířky grafu ankety pro jednu volbu (0-100)
    public function getWidthOfGraphToChoice($choice) 
    {
        return round((100 * $this->choices_count[$choice]) / $this->getChoicesSum());
    }

}

